Foreword
========

.. sidebar::  A Foreword By Paul Everitt

   Paul Everitt is a principal at :term:`Agendaless Consulting`.
   Before his time at Agendaless, he was the co-founder of *Digital
   Creations*, which later became *Zope Corporation*.  He has been
   a widely respected member of the Python community since 1994.

Fortunate.

As I reflect upon the BFG web framework and this book by Chris to
document it, I keep coming back to the same word.  Certainly the
conventional wisdom is clear: "Don't we have too many web frameworks,
paired with outdated books?"  Yes we do, but to the contrary and for
that very reason, we are fortunate to have this book and this
framework.

Chris McDonough first came to work with us at Digital Creations almost
a decade ago, just after there existed a Zope.  We were all pioneers:
the first open source application server, one of the first open source
web companies to get serious investment, and entrants in nearly every
book and article about the open source space.  Zope wasn't just a
unique business model, though.  It really was, as quoted at the time,
one of the places where open source delivered fresh ideas in design
and architecture.

Then a decade happened.  Bubbles burst and the new new thing became
the old new thing, many times in succession.  All of us changed jobs,
worked on a variety of endeavors, and big dreams yielded to small
realities.  Somehow, though the trajectory was unforeseen, we have
orbited back to the same spot.  Older, wiser, but with similar ideas
and familiar faces.  Back to dream again.

We are fortunate to have BFG.  It really does carve out a unique spot
in the Python web frameworks landscape.  It permits the core good
ideas from Zope, while not requiring them.  Moreover, the reason
you'll love it has less to do with Zope and more to do with the old
fashioned stuff:

- A superb commitment to outstanding and constantly updated documentation

- An equal commitment to quality: test coverage, performance, and
  documented compatibility

- Adult supervision and minimalism in the design, with "pay only for
  what you eat" simplicity

For those of us from the Zope world, BFG permits our still-unique
ideas while teleporting us into the modern world of Python web
programming.  It is fascinating, liberating, and rejuvenating.  We are
able to cast off old sins and legitimately reclaim the title of best
damn game in town.  Quite a coup: whether you considered Zope but
turned away, or became an adopter, you'll find BFG the new new new
thing.

We are also fortunate to have this book.  We never had such a resource
in Zope, even though we funded the writing of the first book a decade
ago.  In retrospect, the answer is obvious: a second group tried to
retrofit a book onto code created by the first group.  The true magic
in BFG is that the top-notch documentation is written by the same
person as the top-notch code, a person with equal passion and
commitment to both.  Rarely are we so fortunate.

Which brings us to the final point.  We are fortunate to have Chris.
I personally consider myself lucky to have worked with him and to be
his friend this past decade.  He has changed my thinking in numerous
ways, fundamentally improving the way I view many things.  He's the
best person I know in the world of open source, and I get to be in
business with him.  Fortunate indeed.

I very much hope you enjoy this book and get involved with BFG.  We
use it for applications as small as "hello world" demos up to
scalable, re-usable, half-a-million-dollar projects.  May you find
BFG, and the book, to be a high-quality, honest, and durable framework
choice for your work as well.
